summaryrefslogtreecommitdiffstats
path: root/karbon/karbon_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/karbon_part.h')
-rw-r--r--karbon/karbon_part.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/karbon/karbon_part.h b/karbon/karbon_part.h
index 9c9ae91a..34e0e04b 100644
--- a/karbon/karbon_part.h
+++ b/karbon/karbon_part.h
@@ -73,7 +73,7 @@ public:
void insertObject( VObject* object );
/// insert a command into the undo/redo-history:
- void addCommand( VCommand* cmd, bool repaint = false );
+ void addCommand( VCommand* cmd, bool tqrepaint = false );
// access static document:
VDocument& document() { return m_doc; }
@@ -102,13 +102,13 @@ public:
void initConfig();
unsigned int maxRecentFiles() const { return m_maxRecentFiles; }
- void setPageLayout( KoPageLayout& layout, KoUnit::Unit _unit );
+ void setPageLayout( KoPageLayout& tqlayout, KoUnit::Unit _unit );
bool mergeNativeFormat( const TQString & file );
public slots:
- /// repaint all views attached to this koDocument
- void repaintAllViews( bool repaint = true );
+ /// tqrepaint all views attached to this koDocument
+ void repaintAllViews( bool tqrepaint = true );
void repaintAllViews( const KoRect& );
void slotDocumentRestored();
void slotCommandExecuted( VCommand * );